/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.messages;

/**
 * A Message can be used to indicate Errors, Info or Success to the user.
 * 
 * @author aglomann
 * 
 */
public abstract class Message {

	private final String message;
	private final MessageLevel messageLevel;

	/**
	 * Constructor
	 * 
	 * @param message
	 *            the message text
	 * @param level
	 *            the {@link MessageLevel}
	 */
	Message(final String message, final MessageLevel level) {
		if (message == null || level == null) {
			throw new NullPointerException("None of the arguments must be null: Message: " + message + "; Level: " + level);
		}
		this.message = message;
		this.messageLevel = level;
	}

	/**
	 * @return the message text of this message
	 */
	public String getMessage() {
		return message;
	}

	/**
	 * 
	 * @return the {@link MessageLevel} of this message
	 */
	public MessageLevel getMessageLevel() {
		return messageLevel;
	}

	@Override
	public String toString() {
		return "Message [message=" + message + ", messageLevel=" + messageLevel + "]";
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((message == null) ? 0 : message.hashCode());
		result = prime * result + ((messageLevel == null) ? 0 : messageLevel.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Message other = (Message) obj;
		if (message == null) {
			if (other.message != null)
				return false;
		} else if (!message.equals(other.message))
			return false;
		if (messageLevel != other.messageLevel)
			return false;
		return true;
	}

}
