/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.view;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.lucubrators.honeycomb.core.controller.ControllerResult;
import net.lucubrators.honeycomb.core.view.ViewContext;
import net.lucubrators.honeycomb.core.view.exceptions.CombRenderingException;

public class RequestDispatcherViewContext implements ViewContext {

	private final HttpServletRequest	request;
	private final HttpServletResponse	response;
	private final ControllerResult		controllerResult;

	public RequestDispatcherViewContext(final HttpServletRequest request, final HttpServletResponse response, final ControllerResult controllerResult) {
		this.request = request;
		this.response = response;
		this.controllerResult = controllerResult;
	}

	@Override
	public void include(final String path) {
		try {
			request.getRequestDispatcher(path).include(request, response);
		} catch (ServletException e) {
			throw new CombRenderingException("Could not include " + path, e);
		} catch (IOException e) {
			throw new CombRenderingException("Could not include " + path, e);
		}
	}

	@Override
	public void write(final String toWrite) {
		PrintWriter writer;
		try {
			writer = response.getWriter();
		} catch (IOException e) {
			throw new CombRenderingException("Could not write to response", e);
		}
		writer.flush();
		writer.write(toWrite);
		writer.flush();
	}

	@Override
	public ControllerResult getControllerResult() {
		return this.controllerResult;
	}

	@Override
	public HttpServletResponse getResponse() {
		return response;
	}

	@Override
	public HttpServletRequest getRequest() {
		return request;
	}

}
